==> api-0.9.0-sources.jar: eu/fispace/api/wc/WeatherCondition.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.07.17 a las 08:57:16 AM CEST 
//


package eu.fispace.api.wc;

import java.io.Serializable;
import java.util.Calendar;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="date" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
 *         &lt;element name="cityName" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="cityId" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="countryCode" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="temperature" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="humidity" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="rain" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="snow" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windDirection" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windGustSpeed" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windsSpeed" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "date",
    "cityName",
    "cityId",
    "countryCode",
    "temperature",
    "humidity",
    "rain",
    "snow",
    "windDirection",
    "windGustSpeed",
    "windsSpeed"
})
@XmlRootElement(name = "WeatherCondition")
public class WeatherCondition
    implements Serializable, ToString
{

    @XmlElement(required = true, type = String.class)
    @XmlJavaTypeAdapter(Adapter1 .class)
    @XmlSchemaType(name = "dateTime")
    protected Calendar date;
    @XmlElement(required = true)
    protected String cityName;
    @XmlElement(required = true)
    protected String cityId;
    @XmlElement(required = true)
    protected String countryCode;
    @XmlElement(required = true)
    protected String temperature;
    @XmlElement(required = true)
    protected String humidity;
    @XmlElement(required = true)
    protected String rain;
    @XmlElement(required = true)
    protected String snow;
    @XmlElement(required = true)
    protected String windDirection;
    @XmlElement(required = true)
    protected String windGustSpeed;
    @XmlElement(required = true)
    protected String windsSpeed;

    /**
     * Obtiene el valor de la propiedad date.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Calendar getDate() {
        return date;
    }

    /**
     * Define el valor de la propiedad date.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDate(Calendar value) {
        this.date = value;
    }

    public boolean isSetDate() {
        return (this.date!= null);
    }

    /**
     * Obtiene el valor de la propiedad cityName.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCityName() {
        return cityName;
    }

    /**
     * Define el valor de la propiedad cityName.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCityName(String value) {
        this.cityName = value;
    }

    public boolean isSetCityName() {
        return (this.cityName!= null);
    }

    /**
     * Obtiene el valor de la propiedad cityId.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCityId() {
        return cityId;
    }

    /**
     * Define el valor de la propiedad cityId.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCityId(String value) {
        this.cityId = value;
    }

    public boolean isSetCityId() {
        return (this.cityId!= null);
    }

    /**
     * Obtiene el valor de la propiedad countryCode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCountryCode() {
        return countryCode;
    }

    /**
     * Define el valor de la propiedad countryCode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCountryCode(String value) {
        this.countryCode = value;
    }

    public boolean isSetCountryCode() {
        return (this.countryCode!= null);
    }

    /**
     * Obtiene el valor de la propiedad temperature.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemperature() {
        return temperature;
    }

    /**
     * Define el valor de la propiedad temperature.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemperature(String value) {
        this.temperature = value;
    }

    public boolean isSetTemperature() {
        return (this.temperature!= null);
    }

    /**
     * Obtiene el valor de la propiedad humidity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHumidity() {
        return humidity;
    }

    /**
     * Define el valor de la propiedad humidity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHumidity(String value) {
        this.humidity = value;
    }

    public boolean isSetHumidity() {
        return (this.humidity!= null);
    }

    /**
     * Obtiene el valor de la propiedad rain.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRain() {
        return rain;
    }

    /**
     * Define el valor de la propiedad rain.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRain(String value) {
        this.rain = value;
    }

    public boolean isSetRain() {
        return (this.rain!= null);
    }

    /**
     * Obtiene el valor de la propiedad snow.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSnow() {
        return snow;
    }

    /**
     * Define el valor de la propiedad snow.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSnow(String value) {
        this.snow = value;
    }

    public boolean isSetSnow() {
        return (this.snow!= null);
    }

    /**
     * Obtiene el valor de la propiedad windDirection.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindDirection() {
        return windDirection;
    }

    /**
     * Define el valor de la propiedad windDirection.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindDirection(String value) {
        this.windDirection = value;
    }

    public boolean isSetWindDirection() {
        return (this.windDirection!= null);
    }

    /**
     * Obtiene el valor de la propiedad windGustSpeed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindGustSpeed() {
        return windGustSpeed;
    }

    /**
     * Define el valor de la propiedad windGustSpeed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindGustSpeed(String value) {
        this.windGustSpeed = value;
    }

    public boolean isSetWindGustSpeed() {
        return (this.windGustSpeed!= null);
    }

    /**
     * Obtiene el valor de la propiedad windsSpeed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindsSpeed() {
        return windsSpeed;
    }

    /**
     * Define el valor de la propiedad windsSpeed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindsSpeed(String value) {
        this.windsSpeed = value;
    }

    public boolean isSetWindsSpeed() {
        return (this.windsSpeed!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            Calendar theDate;
            theDate = this.getDate();
            strategy.appendField(locator, this, "date", buffer, theDate);
        }
        {
            String theCityName;
            theCityName = this.getCityName();
            strategy.appendField(locator, this, "cityName", buffer, theCityName);
        }
        {
            String theCityId;
            theCityId = this.getCityId();
            strategy.appendField(locator, this, "cityId", buffer, theCityId);
        }
        {
            String theCountryCode;
            theCountryCode = this.getCountryCode();
            strategy.appendField(locator, this, "countryCode", buffer, theCountryCode);
        }
        {
            String theTemperature;
            theTemperature = this.getTemperature();
            strategy.appendField(locator, this, "temperature", buffer, theTemperature);
        }
        {
            String theHumidity;
            theHumidity = this.getHumidity();
            strategy.appendField(locator, this, "humidity", buffer, theHumidity);
        }
        {
            String theRain;
            theRain = this.getRain();
            strategy.appendField(locator, this, "rain", buffer, theRain);
        }
        {
            String theSnow;
            theSnow = this.getSnow();
            strategy.appendField(locator, this, "snow", buffer, theSnow);
        }
        {
            String theWindDirection;
            theWindDirection = this.getWindDirection();
            strategy.appendField(locator, this, "windDirection", buffer, theWindDirection);
        }
        {
            String theWindGustSpeed;
            theWindGustSpeed = this.getWindGustSpeed();
            strategy.appendField(locator, this, "windGustSpeed", buffer, theWindGustSpeed);
        }
        {
            String theWindsSpeed;
            theWindsSpeed = this.getWindsSpeed();
            strategy.appendField(locator, this, "windsSpeed", buffer, theWindsSpeed);
        }
        return buffer;
    }

    public WeatherCondition withDate(Calendar value) {
        setDate(value);
        return this;
    }

    public WeatherCondition withCityName(String value) {
        setCityName(value);
        return this;
    }

    public WeatherCondition withCityId(String value) {
        setCityId(value);
        return this;
    }

    public WeatherCondition withCountryCode(String value) {
        setCountryCode(value);
        return this;
    }

    public WeatherCondition withTemperature(String value) {
        setTemperature(value);
        return this;
    }

    public WeatherCondition withHumidity(String value) {
        setHumidity(value);
        return this;
    }

    public WeatherCondition withRain(String value) {
        setRain(value);
        return this;
    }

    public WeatherCondition withSnow(String value) {
        setSnow(value);
        return this;
    }

    public WeatherCondition withWindDirection(String value) {
        setWindDirection(value);
        return this;
    }

    public WeatherCondition withWindGustSpeed(String value) {
        setWindGustSpeed(value);
        return this;
    }

    public WeatherCondition withWindsSpeed(String value) {
        setWindsSpeed(value);
        return this;
    }

}

==> api-0.10.0-sources.jar: eu/fispace/api/wc/WeatherCondition.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.08.13 a las 11:35:07 PM CEST 
//


package eu.fispace.api.wc;

import java.io.Serializable;
import java.util.Calendar;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import eu.limetri.platform.api.ResponseMessage;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.limetri.eu/schemas/platform}ResponseMessage">
 *       &lt;sequence>
 *         &lt;element name="date" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
 *         &lt;element name="cityName" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="cityId" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="countryCode" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="temperature" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="humidity" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="rain" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="snow" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windDirection" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windGustSpeed" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="windsSpeed" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "date",
    "cityName",
    "cityId",
    "countryCode",
    "temperature",
    "humidity",
    "rain",
    "snow",
    "windDirection",
    "windGustSpeed",
    "windsSpeed"
})
@XmlRootElement(name = "WeatherCondition")
public class WeatherCondition
    extends ResponseMessage
    implements Serializable, ToString
{

    @XmlElement(required = true, type = String.class)
    @XmlJavaTypeAdapter(Adapter1 .class)
    @XmlSchemaType(name = "dateTime")
    protected Calendar date;
    @XmlElement(required = true)
    protected String cityName;
    @XmlElement(required = true)
    protected String cityId;
    @XmlElement(required = true)
    protected String countryCode;
    @XmlElement(required = true)
    protected String temperature;
    @XmlElement(required = true)
    protected String humidity;
    @XmlElement(required = true)
    protected String rain;
    @XmlElement(required = true)
    protected String snow;
    @XmlElement(required = true)
    protected String windDirection;
    @XmlElement(required = true)
    protected String windGustSpeed;
    @XmlElement(required = true)
    protected String windsSpeed;

    /**
     * Obtiene el valor de la propiedad date.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Calendar getDate() {
        return date;
    }

    /**
     * Define el valor de la propiedad date.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDate(Calendar value) {
        this.date = value;
    }

    public boolean isSetDate() {
        return (this.date!= null);
    }

    /**
     * Obtiene el valor de la propiedad cityName.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCityName() {
        return cityName;
    }

    /**
     * Define el valor de la propiedad cityName.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCityName(String value) {
        this.cityName = value;
    }

    public boolean isSetCityName() {
        return (this.cityName!= null);
    }

    /**
     * Obtiene el valor de la propiedad cityId.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCityId() {
        return cityId;
    }

    /**
     * Define el valor de la propiedad cityId.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCityId(String value) {
        this.cityId = value;
    }

    public boolean isSetCityId() {
        return (this.cityId!= null);
    }

    /**
     * Obtiene el valor de la propiedad countryCode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCountryCode() {
        return countryCode;
    }

    /**
     * Define el valor de la propiedad countryCode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCountryCode(String value) {
        this.countryCode = value;
    }

    public boolean isSetCountryCode() {
        return (this.countryCode!= null);
    }

    /**
     * Obtiene el valor de la propiedad temperature.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemperature() {
        return temperature;
    }

    /**
     * Define el valor de la propiedad temperature.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemperature(String value) {
        this.temperature = value;
    }

    public boolean isSetTemperature() {
        return (this.temperature!= null);
    }

    /**
     * Obtiene el valor de la propiedad humidity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHumidity() {
        return humidity;
    }

    /**
     * Define el valor de la propiedad humidity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHumidity(String value) {
        this.humidity = value;
    }

    public boolean isSetHumidity() {
        return (this.humidity!= null);
    }

    /**
     * Obtiene el valor de la propiedad rain.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRain() {
        return rain;
    }

    /**
     * Define el valor de la propiedad rain.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRain(String value) {
        this.rain = value;
    }

    public boolean isSetRain() {
        return (this.rain!= null);
    }

    /**
     * Obtiene el valor de la propiedad snow.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSnow() {
        return snow;
    }

    /**
     * Define el valor de la propiedad snow.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSnow(String value) {
        this.snow = value;
    }

    public boolean isSetSnow() {
        return (this.snow!= null);
    }

    /**
     * Obtiene el valor de la propiedad windDirection.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindDirection() {
        return windDirection;
    }

    /**
     * Define el valor de la propiedad windDirection.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindDirection(String value) {
        this.windDirection = value;
    }

    public boolean isSetWindDirection() {
        return (this.windDirection!= null);
    }

    /**
     * Obtiene el valor de la propiedad windGustSpeed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindGustSpeed() {
        return windGustSpeed;
    }

    /**
     * Define el valor de la propiedad windGustSpeed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindGustSpeed(String value) {
        this.windGustSpeed = value;
    }

    public boolean isSetWindGustSpeed() {
        return (this.windGustSpeed!= null);
    }

    /**
     * Obtiene el valor de la propiedad windsSpeed.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWindsSpeed() {
        return windsSpeed;
    }

    /**
     * Define el valor de la propiedad windsSpeed.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWindsSpeed(String value) {
        this.windsSpeed = value;
    }

    public boolean isSetWindsSpeed() {
        return (this.windsSpeed!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            Calendar theDate;
            theDate = this.getDate();
            strategy.appendField(locator, this, "date", buffer, theDate);
        }
        {
            String theCityName;
            theCityName = this.getCityName();
            strategy.appendField(locator, this, "cityName", buffer, theCityName);
        }
        {
            String theCityId;
            theCityId = this.getCityId();
            strategy.appendField(locator, this, "cityId", buffer, theCityId);
        }
        {
            String theCountryCode;
            theCountryCode = this.getCountryCode();
            strategy.appendField(locator, this, "countryCode", buffer, theCountryCode);
        }
        {
            String theTemperature;
            theTemperature = this.getTemperature();
            strategy.appendField(locator, this, "temperature", buffer, theTemperature);
        }
        {
            String theHumidity;
            theHumidity = this.getHumidity();
            strategy.appendField(locator, this, "humidity", buffer, theHumidity);
        }
        {
            String theRain;
            theRain = this.getRain();
            strategy.appendField(locator, this, "rain", buffer, theRain);
        }
        {
            String theSnow;
            theSnow = this.getSnow();
            strategy.appendField(locator, this, "snow", buffer, theSnow);
        }
        {
            String theWindDirection;
            theWindDirection = this.getWindDirection();
            strategy.appendField(locator, this, "windDirection", buffer, theWindDirection);
        }
        {
            String theWindGustSpeed;
            theWindGustSpeed = this.getWindGustSpeed();
            strategy.appendField(locator, this, "windGustSpeed", buffer, theWindGustSpeed);
        }
        {
            String theWindsSpeed;
            theWindsSpeed = this.getWindsSpeed();
            strategy.appendField(locator, this, "windsSpeed", buffer, theWindsSpeed);
        }
        return buffer;
    }

    public WeatherCondition withDate(Calendar value) {
        setDate(value);
        return this;
    }

    public WeatherCondition withCityName(String value) {
        setCityName(value);
        return this;
    }

    public WeatherCondition withCityId(String value) {
        setCityId(value);
        return this;
    }

    public WeatherCondition withCountryCode(String value) {
        setCountryCode(value);
        return this;
    }

    public WeatherCondition withTemperature(String value) {
        setTemperature(value);
        return this;
    }

    public WeatherCondition withHumidity(String value) {
        setHumidity(value);
        return this;
    }

    public WeatherCondition withRain(String value) {
        setRain(value);
        return this;
    }

    public WeatherCondition withSnow(String value) {
        setSnow(value);
        return this;
    }

    public WeatherCondition withWindDirection(String value) {
        setWindDirection(value);
        return this;
    }

    public WeatherCondition withWindGustSpeed(String value) {
        setWindGustSpeed(value);
        return this;
    }

    public WeatherCondition withWindsSpeed(String value) {
        setWindsSpeed(value);
        return this;
    }

}
